Trait ToStatsString

pub trait ToStatsString {
    const UNIT_SHORT: &str;

    // Required method
    fn to_stats_string(&self) -> String;
}
Convert a value to a string in a unit and corresponding representation suitable for the stats here.

Required Associated Constants

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl ToStatsString for u64

Implementors