pub struct Stats<ViewType, const TILE_COUNT: usize> {
pub num_values: usize,
pub sum: u128,
pub average: FixedU128<U32>,
pub median: u64,
pub variance: FixedU128<U32>,
pub tiles: Vec<u64>,
/* private fields */
}Expand description
ViewType is perhaps a bit of a misnomer: simply the type that
the statistics is made for, e.g. NanoTime. But that type must,
for full functionality, support conversion to and from u64, and
ToStatsString for viewing.
Fields
num_values: usizesum: u128average: FixedU128<U32>median: u64Interpolated and rounded up for even numbers of input values.
variance: FixedU128<U32>mean squared difference from the mean
tiles: Vec<u64>Percentiles or in TILE_COUNT number of sections. Sample
count is the index, the sample value there is the value in the
vector. tiles[0] is the mininum, tiles[TILE_COUNT] the
maximum sample value. Cut-offs are inclusive, i.e. the index
is rounded up (shows the value of the next item if it falls at
least the distance 0.5 between items).
Implementations
Sourceimpl<ViewType, const TILE_COUNT: usize> Stats<ViewType, TILE_COUNT>
impl<ViewType, const TILE_COUNT: usize> Stats<ViewType, TILE_COUNT>
Sourcepub fn average_u64(&self) -> u64
pub fn average_u64(&self) -> u64
Rounded
pub fn variance_f64(&self) -> f64
Sourcepub fn standard_deviation_u64(&self) -> u64
pub fn standard_deviation_u64(&self) -> u64
sqrt(variance) as u64, since our conversions to ms etc. are on that type; bummer to lose f64 precision, though. Rounded.
Sourcepub fn get(&self, field: StatsField<TILE_COUNT>) -> u64
pub fn get(&self, field: StatsField<TILE_COUNT>) -> u64
Get the value for the given field (and ending up untyped! But from_values was always untyped, too.)
pub fn column_of_field(field: StatsField<TILE_COUNT>) -> usize
pub fn field_type_is_count(field: StatsField<TILE_COUNT>) -> bool
Sourcepub fn from_values_from_field(
field: StatsField<TILE_COUNT>,
vals: Vec<WeightedValue>,
) -> Result<SubStats<ViewType, TILE_COUNT>, StatsError>
pub fn from_values_from_field( field: StatsField<TILE_COUNT>, vals: Vec<WeightedValue>, ) -> Result<SubStats<ViewType, TILE_COUNT>, StatsError>
Make stats from values from field field: this determines the
ViewType of the resulting Stats struct: count or ViewType.
Sourcepub fn from_values(vals: Vec<WeightedValue>) -> Result<Self, StatsError>
pub fn from_values(vals: Vec<WeightedValue>) -> Result<Self, StatsError>
tiles_count is how many ‘tiles’ to build, for percentiles
give the number 101. (Needs to own vals for sorting,
internally.)