pub trait ToStatsString {
const UNIT_SHORT: &str;
// Required method
fn to_stats_string(&self) -> String;
}Expand description
Convert a value to a string in a unit and corresponding representation suitable for the stats here.
Required Associated Constants
const UNIT_SHORT: &str
Required Methods
fn to_stats_string(&self) -> String
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.